@@ -102,12 +102,12 @@ ggcorrmat <- function(data,
   )
 
   # type of correlation and if it is a partial correlation
-  r.method.text <- gsub(" correlation", "", unique(mpc_df$Method))
+  r.method.text <- gsub(" correlation", "", unique(mpc_df$Method), fixed = TRUE)
   r.type <- ifelse(partial, "correlation (partial):", "correlation:")
 
   # plot ------------------------------------------
 
-  check_if_installed("ggcorrplot")
+  insight::check_if_installed("ggcorrplot")
 
   # legend title with information about correlation type and sample size
   if (!anyNA(data) || partial) {
